Skip to contents

The iNZightMR package provides a suite of functions which can be used in the analysis of multiple response data. It is used in the iNZight software package.

Author

Junjie Zeng, Tom Elliott