Calculates required proportions, their differences, variance-covariance matrices, standard errors of differences, and comparison intervals for differences, over all of the data. To compute values over various subsets of another explanatory variable, see by.
Examples
mr <- iNZightMR(online ~ onlinegame + onlinevideo + onlinemusic,
data = census.at.school.5000)
mrp <- mroPara(mr)