R/iNZightMR-package.R
iNZightMR-package.Rd
The iNZightMR package provides a suite of functions which can be used in the analysis of multiple response data. It is used in the iNZight software package.
Useful links:
https://inzight.nz
https://inzightvit.github.io/iNZightMR/
Report bugs at https://github.com/iNZightVIT/iNZightMR/issues
Junjie Zeng, Tom Elliott