Learn R Programming

iNZightMR (version 2.3.0)

iNZightMR-package: iNZightMR: Multiple Response Data Analysis

Description

The iNZightMR package provides a suite of functions which can be used in the analysis of multiple response data. It is used in the iNZight software package.

Arguments

Author

Junjie Zeng, Tom Elliott