Learn R Programming

iNZightMR (version 2.3.0)

mroPara: Calculate MRO inference

Description

Calculates required proportions, their differences, variance-covariance matrices, standard errors of differences, and comparison intervals for differences, over all of the data. To compute values over various subsets of another explanatory variable, see by.

Usage

mroPara(obj, conf.levels = 1.96, nonparallel = NULL)

Value

An object of class mrocalc

Arguments

obj

an MRO object created by iNZightMR

conf.levels

confidence level to use, default is 1.96 for 95% intervals

nonparallel

Should these things be parallel?

See Also

iNZightMR

Examples

Run this code
mr <- iNZightMR(online ~ onlinegame + onlinevideo + onlinemusic,
    data = census.at.school.5000)
mrp <- mroPara(mr)

Run the code above in your browser using DataLab